@@ -8,7 +8,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkMacInt.h 1.33 96/06/20 18:18:42
+ * SCCS: @(#) tkMacInt.h 1.41 96/09/05 13:38:41
  */
 
 #ifndef _TKMACINT
@@ -42,8 +42,7 @@ typedef struct TkWindowPrivate MacDrawable;
  */
 #define TK_SCROLLBAR_GROW	1
 #define TK_CLIP_INVALID		2
-#define TK_NEVER_MAPPED		4
-#define TK_EMBED_WINDOW		8
+#define TK_EMBED_WINDOW		4
 
 /*
  * Defines use for the flags argument to TkGenWMConfigureEvent.
@@ -52,12 +51,17 @@ typedef struct TkWindowPrivate MacDrawable;
 #define TK_SIZE_CHANGED		2
 #define TK_BOTH_CHANGED		3
 
+/*
+ * Variables shared among various Mac Tk modules but are not
+ * exported to the outside world.
+ */
+extern int tkMacAppInFront;
+
 /*
  * Internal procedures shared among Macintosh Tk modules but not exported
  * to the outside world:
  */
 
-extern Time		GenerateTime _ANSI_ARGS_(());
 extern int		HandleWMEvent _ANSI_ARGS_((EventRecord *theEvent));
 extern void		InvalClipRgns _ANSI_ARGS_((TkWindow *winPtr));
 extern void 		TkAboutDlg _ANSI_ARGS_((void));
@@ -73,12 +77,14 @@ extern int 		TkGetCharPositions _ANSI_ARGS_((
 extern void		TkGenWMDestroyEvent _ANSI_ARGS_((Tk_Window tkwin));
 extern void		TkGenWMConfigureEvent _ANSI_ARGS_((Tk_Window tkwin,
 			    int x, int y, int width, int height, int flags));
+extern unsigned int	TkMacButtonKeyState _ANSI_ARGS_((void));
 extern int		TkMacConvertEvent _ANSI_ARGS_((EventRecord *eventPtr));
 extern void		tkMacInstallMWConsole _ANSI_ARGS_((
 			    Tcl_Interp *interp));
 extern void		TkMacDoHLEvent _ANSI_ARGS_((EventRecord *theEvent));
 extern void 		TkMacFontInfo _ANSI_ARGS_((Font fontId, short *family,
 			    short *style, short *size));
+extern Time		TkMacGenerateTime _ANSI_ARGS_(());
 extern GWorldPtr 	TkMacGetDrawablePort _ANSI_ARGS_((Drawable drawable));
 extern TkWindow * 	TkMacGetScrollbarGrowWindow _ANSI_ARGS_((
 			    TkWindow *winPtr));
@@ -93,23 +99,25 @@ extern void		TkMacPointerDeadWindow _ANSI_ARGS_((TkWindow *winPtr));
 extern int		TkMacResizable _ANSI_ARGS_((TkWindow *winPtr));
 extern void		TkMacSetScrollbarGrow _ANSI_ARGS_((TkWindow *winPtr,
 			    int flag));
+extern void		TkMacSetUpClippingRgn _ANSI_ARGS_((Drawable drawable));
+extern void		TkMacSetUpGraphicsPort _ANSI_ARGS_((GC gc));
 extern void 		TkMacUpdateClipRgn _ANSI_ARGS_((TkWindow *winPtr));
 extern RgnHandle 	TkMacVisableClipRgn _ANSI_ARGS_((TkWindow *winPtr));
-extern void		TkMacWinBounds _ANSI_ARGS_((TkWindow *winPtr,
-			    Rect *bounds));
 extern void		TkResumeClipboard _ANSI_ARGS_((void));
 extern int 		TkSetMacColor _ANSI_ARGS_((unsigned long pixel,
 			    RGBColor *macColor));
-void 			TkSetWMName _ANSI_ARGS_((TkWindow *winPtr,
+extern void 		TkSetWMName _ANSI_ARGS_((TkWindow *winPtr,
 			    Tk_Uid titleUid));
 extern void		TkSuspendClipboard _ANSI_ARGS_((void));
 extern void		TkUpdateCursor _ANSI_ARGS_((TkWindow *winPtr));
+extern void		TkMacWinBounds _ANSI_ARGS_((TkWindow *winPtr,
+			    Rect *geometry));
 extern void		TkMacWindowOffset _ANSI_ARGS_((WindowRef wRef, 
 			    int *xOffset, int *yOffset));
 extern int		TkWMGrowToplevel _ANSI_ARGS_((WindowRef whichWindow,
 			    Point start));
-extern void		TkMacWMInitBounds _ANSI_ARGS_((TkWindow *winPtr,
-			    Rect *geometry));
+extern int		TkMacZoomToplevel _ANSI_ARGS_((WindowPtr whichWindow, 
+			    Point where, short zoomPart));
 extern Tk_Window	Tk_TopCoordsToWindow _ANSI_ARGS_((Tk_Window tkwin,
 			    int rootX, int rootY, int *newX, int *newY));
 
