@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkMacLibrary.r 1.6 96/10/21 13:02:22
+ * SCCS: @(#) tkMacLibrary.r 1.5 96/10/03 17:54:21
  */
 
 #include <Types.r>
@@ -491,46 +491,3 @@ data 'PICT' (128, purgeable) {
 	$"0E0A 000E 3939 320E 0E07 07F6 F5C8 0002"
 	$"BD00 00FF"
 };
-
-/*
- * Here is the custom file open dialog. This dialog is used instead of
- * the default file dialog if the -filetypes flag is specified.
- */
-
-resource 'DLOG' (130, purgeable) {
-    {0, 0, 195, 344}, dBoxProc, invisible, noGoAway, 0,
-     130, ""
-};
-
-resource 'DITL' (130, "File Open Box", purgeable) {
-    {
-	{135, 252, 155, 332}, Button   {enabled, "Open"},
-	{104, 252, 124, 332}, Button   {enabled, "Cancel"},	    
-        {  0,   0,   0,   0}, HelpItem {disabled, HMScanhdlg {130}},
-        {  8, 235,  24, 337}, UserItem {enabled},
-        { 32, 252,  52, 332}, Button   {enabled, "Eject"},
-        { 60, 252,  80, 332}, Button   {enabled, "Desktop"},    
-        { 29,  12, 159, 230}, UserItem {enabled},
-        {  6,  12,  25, 230}, UserItem {enabled},
-        { 91, 251,  92, 333}, Picture  {disabled, 11},
-        {168,  20, 187, 300}, Control  {enabled, 131} 
-    }
-};
-
-resource 'CNTL' (131, "File Types menu", purgeable) {
-    {168, 20, 187, 300},
-    popupTitleLeftJust,
-    visible,
-    80,
-    132,
-    popupMenuCDEFProc,
-    0,
-    "File Type:"
-};
-
-
-resource 'MENU' (132, preload) {
-    132,
-    textMenuProc,
-    0xFFFF, enabled, "", {}
-};
